@@ -1,9 +1,3 @@
-"""Contains the package version string.
-
-See Also:
-    `PEP 396 <https://www.python.org/dev/peps/pep-0396/>`_
-
-"""
 
 from __future__ import annotations
 
@@ -12,4 +6,7 @@ import pkg_resources
 __all__ = ['__version__']
 
 #: The package version string.
+#:
+#: See Also:
+#:    `PEP 396 <https://www.python.org/dev/peps/pep-0396/>`_
 __version__: str = pkg_resources.require('swim-protocol')[0].version
